mod args;
mod assert;
mod binread_temp;
mod c_enum;
mod calc;
mod custom_writer;
mod endian;
mod r#enum;
mod ignore;
mod import;
mod magic;
mod map;
mod padding;
mod restore_position;
mod simple;
mod top_level_map;
